DataTableProps

Struct DataTableProps 

pub struct DataTableProps {
    pub columns: LocalBoxSignalVec<'static, TableColumn>,
    pub rows: LocalBoxSignalVec<'static, (String, Vec<Dom>)>,
    pub sorted_by: LocalBoxSignal<'static, Option<(String, SortDirection)>>,
    pub on_sort: Box<dyn Fn(String, SortDirection) + 'static>,
    pub on_row_click: Box<dyn Fn(String) + 'static>,
    pub rows_clickable: bool,
    pub apply: Option<Box<dyn FnOnce(DomBuilder<HtmlElement>) -> DomBuilder<HtmlElement> + 'static>>,
}
A themed data table with sortable column headers.

Sorting is controlled: clicking a sortable header invokes on_sort with the column key and the requested direction, and the current order is reflected back through the sorted_by signal (exposed to assistive technology via aria-sort). Rows are (id, cells) pairs; clicking a row invokes on_row_click with its id.

Fields

columns: LocalBoxSignalVec<'static, TableColumn>rows: LocalBoxSignalVec<'static, (String, Vec<Dom>)>sorted_by: LocalBoxSignal<'static, Option<(String, SortDirection)>>on_sort: Box<dyn Fn(String, SortDirection) + 'static>on_row_click: Box<dyn Fn(String) + 'static>rows_clickable: boolapply: Option<Box<dyn FnOnce(DomBuilder<HtmlElement>) -> DomBuilder<HtmlElement> + 'static>>

Implementations

Source

impl DataTableProps

pub fn new() -> Self

Source

impl DataTableProps

pub fn columns(self, v: impl Into<Vec<TableColumn>>) -> DataTableProps

pub fn columns_signal_vec( self, v: impl SignalVec<Item = TableColumn> + 'static, ) -> DataTableProps

Source

impl DataTableProps

pub fn rows(self, v: impl Into<Vec<(String, Vec<Dom>)>>) -> DataTableProps

pub fn rows_signal_vec( self, v: impl SignalVec<Item = (String, Vec<Dom>)> + 'static, ) -> DataTableProps

Source

impl DataTableProps

pub fn sorted_by(self, v: Option<(String, SortDirection)>) -> DataTableProps

pub fn sorted_by_signal( self, v: impl Signal<Item = Option<(String, SortDirection)>> + 'static, ) -> DataTableProps

Source

impl DataTableProps

pub fn on_sort( self, v: impl Fn(String, SortDirection) + 'static, ) -> DataTableProps

Source

impl DataTableProps

pub fn on_row_click(self, v: impl Fn(String) + 'static) -> DataTableProps

Source

impl DataTableProps

pub fn rows_clickable(self, v: bool) -> DataTableProps

Set when row clicks are meaningful; adds hover/cursor affordances

Source

impl DataTableProps

pub fn apply( self, v: impl FnOnce(DomBuilder<HtmlElement>) -> DomBuilder<HtmlElement> + 'static, ) -> DataTableProps